@@ -1,13 +1,12 @@
 package aws
 
 import (
-	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/enumeration/resource"
+	"github.com/snyk/driftctl/enumeration/resource/aws"
 )
 
-const AwsIamUserResourceType = "aws_iam_user"
-
 func initAwsIAMUserMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
-	resourceSchemaRepository.SetNormalizeFunc(AwsIamUserResourceType, func(res *resource.Resource) {
+	resourceSchemaRepository.SetNormalizeFunc(aws.AwsIamUserResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		permissionsBoundary, exist := val.Get("permissions_boundary")
 		if exist && permissionsBoundary == "" {
@@ -15,5 +14,4 @@ func initAwsIAMUserMetaData(resourceSchemaRepository resource.SchemaRepositoryIn
 		}
 		val.SafeDelete([]string{"force_destroy"})
 	})
-	resourceSchemaRepository.SetFlags(AwsIamUserResourceType, resource.FlagDeepMode)
 }
