@@ -1,16 +1,12 @@
 package aws
 
 import (
-	"bytes"
-	"fmt"
 	"strconv"
 
-	"github.com/hashicorp/terraform/helper/hashcode"
-	"github.com/snyk/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/enumeration/resource"
+	"github.com/snyk/driftctl/enumeration/resource/aws"
 )
 
-const AwsNetworkACLRuleResourceType = "aws_network_acl_rule"
-
 var protocolsNumbers = map[string]int{
 	// defined at https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml
 	"all":             -1,
@@ -161,52 +157,7 @@ var protocolsNumbers = map[string]int{
 }
 
 func initAwsNetworkACLRuleMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
-	resourceSchemaRepository.SetFlags(AwsNetworkACLRuleResourceType, resource.FlagDeepMode)
-	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsNetworkACLRuleResourceType, func(res *resource.Resource) map[string]string {
-
-		ruleNumber := strconv.FormatInt(int64(*res.Attrs.GetFloat64("rule_number")), 10)
-		if ruleNumber == "32767" {
-			ruleNumber = "*"
-		}
-
-		attrs := map[string]string{
-			"Network":     *res.Attrs.GetString("network_acl_id"),
-			"Egress":      strconv.FormatBool(*res.Attrs.GetBool("egress")),
-			"Rule number": ruleNumber,
-		}
-
-		if proto := res.Attrs.GetString("protocol"); proto != nil {
-			if *proto == "-1" {
-				*proto = "All"
-			}
-			attrs["Protocol"] = *proto
-		}
-
-		if res.Attrs.GetFloat64("from_port") != nil && res.Attrs.GetFloat64("to_port") != nil {
-			attrs["Port range"] = fmt.Sprintf("%d - %d",
-				int64(*res.Attrs.GetFloat64("from_port")),
-				int64(*res.Attrs.GetFloat64("to_port")),
-			)
-		}
-
-		if cidr := res.Attrs.GetString("cidr_block"); cidr != nil && *cidr != "" {
-			attrs["CIDR"] = *cidr
-		}
-
-		if cidr := res.Attrs.GetString("ipv6_cidr_block"); cidr != nil && *cidr != "" {
-			attrs["CIDR"] = *cidr
-		}
-
-		return attrs
-	})
-	resourceSchemaRepository.SetResolveReadAttributesFunc(AwsNetworkACLRuleResourceType, func(res *resource.Resource) map[string]string {
-		return map[string]string{
-			"network_acl_id": *res.Attrs.GetString("network_acl_id"),
-			"rule_number":    strconv.FormatInt(int64(*res.Attrs.GetFloat64("rule_number")), 10),
-			"egress":         strconv.FormatBool(*res.Attrs.GetBool("egress")),
-		}
-	})
-	resourceSchemaRepository.SetNormalizeFunc(AwsNetworkACLRuleResourceType, func(res *resource.Resource) {
+	resourceSchemaRepository.SetNormalizeFunc(aws.AwsNetworkACLRuleResourceType, func(res *resource.Resource) {
 		res.Attrs.DeleteIfDefault("icmp_code")
 		res.Attrs.DeleteIfDefault("icmp_type")
 
@@ -229,7 +180,7 @@ func initAwsNetworkACLRuleMetaData(resourceSchemaRepository resource.SchemaRepos
 		// While reading remote we always got protocol as a number.
 		// We cannot predict how the user decided to write the protocol on IaC side.
 		// This workaround is mandatory to harmonize resources ID
-		res.Id = CreateNetworkACLRuleID(
+		res.Id = aws.CreateNetworkACLRuleID(
 			*res.Attrs.GetString("network_acl_id"),
 			int(*res.Attrs.GetFloat64("rule_number")),
 			*res.Attrs.GetBool("egress"),
@@ -241,12 +192,3 @@ func initAwsNetworkACLRuleMetaData(resourceSchemaRepository resource.SchemaRepos
 		res.Attrs.DeleteIfDefault("ipv6_cidr_block")
 	})
 }
-
-func CreateNetworkACLRuleID(networkAclId string, ruleNumber int, egress bool, protocol string) string {
-	var buf bytes.Buffer
-	buf.WriteString(fmt.Sprintf("%s-", networkAclId))
-	buf.WriteString(fmt.Sprintf("%d-", ruleNumber))
-	buf.WriteString(fmt.Sprintf("%t-", egress))
-	buf.WriteString(fmt.Sprintf("%s-", protocol))
-	return fmt.Sprintf("nacl-%d", hashcode.String(buf.String()))
-}
